@@ -23,7 +23,7 @@
  * #LauncherFavorites will store favorite #LauncherApplication applications for easy access
  */
 
- 
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -38,7 +38,7 @@ G_DEFINE_TYPE (LauncherFavorites, launcher_favorites, G_TYPE_OBJECT)
 #define LAUNCHER_FAVORITES_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE(obj, \
         LAUNCHER_TYPE_FAVORITES, LauncherFavoritesPrivate))
 
-#define FAV_PATH "/apps/netbook-launcher/favorites"
+#define FAV_PATH "/desktop/unity/launcher/favorites"
 #define FAV_LIST FAV_PATH"/favorites_list"
 
 struct _LauncherFavoritesPrivate
@@ -111,11 +111,12 @@ get_path (const gchar *uid, const gchar *key)
 /*
  * Public Methods
  */
+
 /**
- * launcher_favorites_get_favorites:
+ * launcher_favorites_get_favorites
  * @favorites: A #LauncherFavorites object
  *
- * retrives a #GCONF_VALUE_LIST of favorite applications 
+ * Retrives a #GCONF_VALUE_LIST of favorite applications
  *
  * Returns: An unowned #GSList
  */
@@ -133,11 +134,11 @@ launcher_favorites_get_favorites (LauncherFavorites *favorites)
 }
 
 /**
- * launcher_favorites_set_favorites:
+ * launcher_favorites_set_favorites
  * @self: a #LauncherFavorites object
  * @list: A #GSList object
  *
- * Allows you to set all the favorite applications at once using one gslist, 
+ * Allows you to set all the favorite applications at once using one gslist,
  * see gconf_client_set_list() for list stucture
  */
 void
@@ -155,12 +156,12 @@ launcher_favorites_set_favorites (LauncherFavorites *self,
 }
 
 /**
- * launcher_favorites_add_favorite:
+ * launcher_favorites_add_favorite
  * @favorites: a #LauncherFavorites object
  * @uid: a unique string
  *
  * Allows you to add a new favorite to the list of favorites, you need to supply
- * a unique id 
+ * a unique id
  *
  * Returns: A boolean indicating wheather the function completed succesfully or not
  */
@@ -206,12 +207,12 @@ launcher_favorites_add_favorite (LauncherFavorites *favorites,
 }
 
 /**
- * launcher_favorites_remove_favorite:
+ * launcher_favorites_remove_favorite
  * @favorites: a #LauncherFavorites object
  * @uid: a unique string
  *
  * Allows you to remove a favorite to the list of favorites, you need to supply
- * a unique id 
+ * a unique id
  *
  * Returns: A boolean indicating wheather the function completed succesfully or not
  */
@@ -588,3 +589,29 @@ launcher_favorites_set_list   (LauncherFavorites *favorites,
       g_error_free (error);
     }
 }
+
+gboolean
+launcher_favorites_get_readonly (LauncherFavorites *favorites,
+                                 const gchar   *uid,
+                                 const gchar   *key)
+{
+  LauncherFavoritesPrivate *priv;
+  gchar  *path;
+  GError *error = NULL;
+  gboolean is_writable = FALSE;
+  g_return_val_if_fail (LAUNCHER_IS_FAVORITES (favorites), FALSE);
+  g_return_val_if_fail (uid, FALSE);
+  g_return_val_if_fail (key, FALSE);
+  priv = favorites->priv;
+
+  path = get_path (uid, key);
+  is_writable = gconf_client_key_is_writable (priv->client, path, &error);
+  g_free (path);
+
+  if (error)
+    {
+      g_warning ("Unable to check for readonly path %s: %s", path, error->message);
+      g_error_free (error);
+    }
+  return !is_writable;
+}
