@@ -22,12 +22,10 @@
 
 #include <launcher/launcher-application.h>
 #include <launcher/launcher-appman.h>
-#include <launcher/launcher-category.h>
 #include <launcher/launcher-favorites.h>
 #include <launcher/launcher-folder-bookmarks.h>
 #include <launcher/launcher-folder.h>
 #include <launcher/launcher-icon-utils.h>
-#include <launcher/launcher-menu.h>
 #include <launcher/launcher-session.h>
 
 #endif /* _LAUNCHER_H_ */
